Module predicates

Module predicates 

Character predicates.

Structs

CharEqual
Checks whether the character is equal to C.
CharGreater
Checks whether the character is greater than C.
CharGreaterOrEqual
Checks whether the character is greater than or equal to C.
CharLess
Checks whether the character is less than C.
CharLessOrEqual
Checks whether the character is less than or equal to C.
CharNotEqual
Checks whether the character is not equal to C.

Constants

NULL
Represents the null character.

Type Aliases

CharClosed
Represents [C, D] intervals.
CharClosedOpen
Represents [C, D) intervals.
CharNonNull
Checks whether the character is non-NULL.
CharNull
Checks whether the character is NULL.
CharOpen
Represents (C, D) intervals.
CharOpenClosed
Represents (C, D] intervals.